Type: Package
Package: immunogenetr
Title: A Comprehensive Toolkit for Clinical HLA Informatics
Version: 1.3.0
Authors@R: c(
    person("Nicholas", "Brown", , "nicholas.brown@pennmedicine.upenn.edu", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-0046-2315")),
    person("Busra", "Coskun", , "bcoskun@sas.upenn.edu", role = "aut",
           comment = c(ORCID = "0009-0008-6828-3453"))
  )
Maintainer: Nicholas Brown <nicholas.brown@pennmedicine.upenn.edu>
Description: A comprehensive toolkit for clinical Human Leukocyte Antigen (HLA) informatics, built on 'tidyverse' <https://tidyverse.tidyverse.org/> principles and making use of genotype list string (GL string, Mack et al. (2023) <doi:10.1111/tan.15126>) for storing and computing HLA genotype data.  Specific functionalities include: coercion of HLA data in tabular format to and from GL string; calculation of matching and mismatching in all directions, with multiple output formats; automatic formatting of HLA data for searching within a GL string; truncation of molecular HLA data to a specific number of fields; and reading HLA genotypes in HML files and extracting the GL string. This library is intended for research use. Any application making use of this package in a clinical setting will need to be independently validated according to local regulations.
License: GPL (>= 3)
URL: https://immunogenetr.org,
        https://github.com/k96nb01/immunogenetr_package,
        https://doi.org/10.1016/j.humimm.2025.111619
BugReports: https://github.com/k96nb01/immunogenetr_package/issues
Depends: R (>= 4.1.0)
Imports: cli (>= 3.0.0), dplyr (>= 1.1.1), purrr (>= 1.0.2), rlang (>=
        1.1.2), stringi (>= 1.7.0), stringr (>= 1.5.0), tibble (>=
        3.1.3), tidyr (>= 1.3.0), tidyselect (>= 1.2.0), xml2 (>=
        1.3.6)
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-26 04:51:42 UTC; drnic
Author: Nicholas Brown [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-0046-2315>),
  Busra Coskun [aut] (ORCID: <https://orcid.org/0009-0008-6828-3453>)
Repository: CRAN
Date/Publication: 2026-05-26 08:50:10 UTC
Built: R 4.6.0; ; 2026-05-26 10:29:44 UTC; unix
