# Generated by roxygen2: do not edit by hand

export(GLstring_expand_longer)
export(GLstring_gene_copies_combine)
export(GLstring_genes)
export(GLstring_genes_expanded)
export(GLstring_genotype_ambiguity)
export(GLstring_regex)
export(GLstring_to_ambiguity_table)
export(HLA_column_repair)
export(HLA_columns_to_GLstring)
export(HLA_match_number)
export(HLA_match_summary_HCT)
export(HLA_mismatch_alleles)
export(HLA_mismatch_base)
export(HLA_mismatch_logical)
export(HLA_mismatch_number)
export(HLA_mismatched_alleles)
export(HLA_prefix_add)
export(HLA_prefix_remove)
export(HLA_truncate)
export(HLA_validate)
export(ambiguity_table_to_GLstring)
export(read_HML)
importFrom(cli,cli_abort)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,bind_rows)
importFrom(dplyr,contains)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,na_if)
importFrom(dplyr,rename_with)
importFrom(dplyr,select)
importFrom(dplyr,starts_with)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(purrr,map)
importFrom(rlang,caller_env)
importFrom(stringi,stri_endswith_fixed)
importFrom(stringi,stri_extract_first_regex)
importFrom(stringi,stri_split_fixed)
importFrom(stringi,stri_startswith_fixed)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_escape)
importFrom(stringr,str_extract)
importFrom(stringr,str_flatten)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unite)
importFrom(tidyselect,all_of)
importFrom(xml2,read_xml)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_ns)
importFrom(xml2,xml_text)
