#' Data on HLA alleles in the 2008 HLA dictionary
#'
#' @docType data
#'
#' @usage data(HLA_dictionary)
#'
#' @format
#' A tibble:
#' \describe{
#'   \item{IPD.Accession}{IPD-IMGT/HLA Accession number}
#'   \item{HLA.Allele}{HLA allele name}
#'   \item{WHO.Assigned.Type}{WHO-assigned serologic equivalent}
#'   ...
#' }
#'
#' @keywords datasets
#'
#' @source <https://doi.org/10.1111/j.1399-0039.2008.01183.x>
#'
"HLA_dictionary"
