#' Synthetic HLA typing data for 10 individuals for the HLA-A, B, C, DRB1, DRB3/4/5,
#' DQB1, DQA1, DPB1 and DPA1 loci.
#'
#' @docType data
#'
#' @usage data(HLA_typing_1)
#'
#' @format
#' A tibble:
#' \describe{
#'   \item{patient}{Patients 1-10}
#'   \item{A1:DPB1_2}{HLA allele names}
#'     ...
#' }
#'
#' @keywords datasets
#'
#' @source Synthetic data from Nicholas K. Brown.
#'
"HLA_typing_1"
