#' Consensus mismatch numbers for every possible allele combination
#' at a single locus, from the 2016 publication.
#'
#' @docType data
#'
#' @usage data(mismatch_table_2016)
#'
#' @format
#' A tibble:
#' \describe{
#'   \item{Patient:Donor}{allele combinations for patient and donor}
#'   \item{#GvH:#Max}{consensus mismatch number for each direction}
#'     ...
#' }
#'
#' @keywords datasets
#'
#' @source <https://www.nature.com/articles/bmt2010132>
#'
"mismatch_table_2016"
