% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mismatch_table_2016-data.R
\docType{data}
\name{mismatch_table_2016}
\alias{mismatch_table_2016}
\title{Consensus mismatch numbers for every possible allele combination
at a single locus, from the 2016 publication.}
\format{
A tibble:
\describe{
  \item{Patient:Donor}{allele combinations for patient and donor}
  \item{#GvH:#Max}{consensus mismatch number for each direction}
    ...
}
}
\source{
<https://www.nature.com/articles/bmt2010132>
}
\usage{
data(mismatch_table_2016)
}
\description{
Consensus mismatch numbers for every possible allele combination
at a single locus, from the 2016 publication.
}
\keyword{datasets}
